( cd boot ; rm -rf vmlinuz )
( cd boot ; ln -sf vmlinuz-generic-2.6.21.5 vmlinuz )
( cd boot ; rm -rf System.map )
( cd boot ; ln -sf System.map-generic-2.6.21.5 System.map )
( cd boot ; rm -rf config )
( cd boot ; ln -sf config-generic-2.6.21.5 config )
